Exceptions - kombu.exceptions — Kombu v0.1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v0.1.0 documentation »
- API Reference »

# Exceptions - kombu.exceptions

exception `kombu.exceptions.` `EnsureExhausted`

  ensure() limit exceeded.

exception `kombu.exceptions.` `MessageStateError`

  The message has already been acknowledged.

exception `kombu.exceptions.` `NotBoundError`

  Trying to call channel dependent method on unbound entity.

exception `kombu.exceptions.` `PoolExhausted`

  All connections acquired.

exception `kombu.exceptions.` `PoolLimitExceeded`

  Can’t add more connections to pool.

exception `kombu.exceptions.` `TimeoutError`

  Operation timed out.

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v0.1.0 documentation »
- API Reference »